/********************************************************************************
*
*	Copyright(C) 2002 - 2003 by OMRON Corporation
*		All Rights Reserved.
*
*	Copyright(C) 2004 - 2005 by Hitachi-Omron Terminal Solutions, Corp.
*		All Rights Reserved.
*
*	Name		: Hitachi-Omron Card Reader DLL Header File
*
*	Filename	: ErrorCode.h
*
*	Caption		: Error codes
*
*	Author		: Hitachi-Omron Terminal Solutions, Corp.
*
*	Revision	: 1.3.1.0
*
*	History		: 
*	----------------------------------------------------------------------------
*	Revision	Date		Author			Description
*	----------------------------------------------------------------------------
*	1.1.0.0		2003/10/19	OMRON			Create new
*	1.3.0.0		2005/04/26	Hitachi-Omron	Added OMCR_FERR_SYS_UNSUPPORTED
*	1.4.0.0		2005/11/07	Hitachi-Omron	Added OMCR_ERR_FUNC_DEV_HOSTWDTEJECT,
*											OMCR_ERR_FUNC_DEV_HOSTWDTRESET,
*											OMCR_ERR_FUNC_DEV_TAMPERERROR
*	1.5.0.0		2005/12/07	Hitachi-Omron	Added OMCR_WRN_FUNC_CLS_CANNOTRECEIVE,
*											OMCR_WRN_FUNC_CLS_COMMUNICATEERROR,
*											OMCR_WRN_FUNC_CLS_AUTHERROR,
*											OMCR_WRN_FUNC_CLS_UNSUPPORTED
********************************************************************************/
/*-------------------------------------------------------------------------------
	DLL Status

   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
  +---+-+-+-------+---------------+-------------------------------+
  |Err|RFU| Type  |     Func      |            Code               |
  +---+-+-+-------+---------------+-------------------------------+
	where
		Err is error status
			00 : Success
			01 : Warning (Commands does not succeed, but transaction can be continued)
			10 : Error (Specific recovery operation is needed)
			11 : Fatal error (Transaction cannot be continued)
		Type is the error / information indivisual type
		Func is Card Reader function (meaningless exclude that Type is "IMCRW")
		Code is the error / information indivisual code
-------------------------------------------------------------------------------*/
#ifndef __OMRON_OMCR_API_ERRORCODE_HEADER__
#define __OMRON_OMCR_API_ERRORCODE_HEADER__


/*==============================================================================
 Define Macro
==============================================================================*/
/* Making error code */
#define ERROR_CODE(Mean,Type,Func,Code) (				\
	((Mean)<<30) | ((Type)<<24) | ((Func)<<16) | (Code)	\
)

/* Status check macro */
#define IS_STATUS_SUCCESS(Status)		(!((Status)&0xC0000000))

/*==============================================================================
 Define category
==============================================================================*/
/* Mean:2bit(0-3). No item should be added. */
#define MEAN_SUCCESS			0		/* Success status */
#define MEAN_WARNING			1		/* Warning (the command is not executed, transaction can be continued) */
#define MEAN_ERROR				2		/* Error (use the specific recovery operation) */
#define MEAN_FATAL				3		/* Fatal error (Fatal error occured in the Card Reader or system. Transaction can not be continued) */

/* Type:4bit(0-15) */
#define TYPE_NOTYPE				0		/* USE this if 'Mean' is 'ERROR_CODE_MEAN_SUCCESS' */
#define TYPE_SYSTEM				1		/* System failure. */
#define TYPE_USERPARAM			2		/* The parameter is invalid. */
#define TYPE_DEVICE				3		/* Device cannot be comminicated. */
#define TYPE_IMCRWFUNC			4		/* Card Reader functional error, look 'Func' status */
#define TYPE_XFS				5		/* XFS error */
#define TYPE_USB				6		/* USB error */

/* Func:8bit(0-255) */
#define FUNC_NOFUNC				0		/* USE this if 'Type' is NOT 'ERROR_CODE_TYPE_IMCRWFUNC' */
#define FUNC_UNKNOWN			0		/* USE this if 'Type' is 'ERROR_CODE_TYPE_IMCRWFUNC' and unknown */
#define FUNC_DEVICE				1		/* Device, Equipment, Mecanical error */
#define FUNC_SOFTWARE			2		/* Firmware error */
#define FUNC_COMMAND			3		/* Invalid command, sequence error */
#define FUNC_MAGCARD			4		/* Magnetic card error */
#define FUNC_CHIPCARD			5		/* Chip card error */
#define FUNC_CONTACTLESS		6		/* Contactless card error */
#define FUNC_MEDIA				7		/* Media error */
#define FUNC_DOWNLOAD			8		/* Dwonload */
#define FUNC_SETTING			9		/* Setting */
#define FUNC_SECURITY			10		/* CIM/MM */
#define FUNC_BATTERY			11		/* Battery */
#define FUNC_BIN				12		/* BIN */
#define FUNC_DIAGNOSTIC			13		/* Diagnostic */
#define FUNC_SAM				14		/* SAM */
#define FUNC_FRAUDDETECT		15		/* Fraud detection */

/*==============================================================================
 Define error codes
==============================================================================*/
/*-------------------------------------------------------------------------------
 Success code
-------------------------------------------------------------------------------*/
#define OMCR_STATUS_SUCCESS						ERROR_CODE(MEAN_SUCCESS, TYPE_NOTYPE, FUNC_NOFUNC, 0)
#define OMCR_STATUS_PENDING						ERROR_CODE(MEAN_SUCCESS, TYPE_NOTYPE, FUNC_NOFUNC, 1)

/*------------------------------------------------------------------------------
 Fatal errors
-------------------------------------------------------------------------------*/
#define OMCR_FERR_SYS_WIN32_ERROR				ERROR_CODE(MEAN_FATAL, TYPE_SYSTEM, FUNC_NOFUNC, 0)				/* Windows32 API return error */
#define OMCR_FERR_SYS_DLL_UNLOAD				ERROR_CODE(MEAN_FATAL, TYPE_SYSTEM, FUNC_NOFUNC, 1)				/* Cannot load DLL */
#define OMCR_FERR_SYS_UNSUPPORTED				ERROR_CODE(MEAN_FATAL, TYPE_SYSTEM, FUNC_NOFUNC, 2)				/* This function is not supporter */

#define OMCR_FERR_DEV_CRNOTFOUND				ERROR_CODE(MEAN_FATAL, TYPE_DEVICE, FUNC_NOFUNC, 0)				/* Card Reader cannot be found */
#define OMCR_FERR_DEV_DISCONNECTED				ERROR_CODE(MEAN_FATAL, TYPE_DEVICE, FUNC_NOFUNC, 1)				/* Cable disconnected */
#define OMCR_FERR_DEV_POWERDOWN					ERROR_CODE(MEAN_FATAL, TYPE_DEVICE, FUNC_NOFUNC, 2)				/* Detecting power down */

/*------------------------------------------------------------------------------
 Normal errors
-------------------------------------------------------------------------------*/
#define OMCR_ERR_USER_INVALIDPARAMETER			ERROR_CODE(MEAN_ERROR, TYPE_USERPARAM, FUNC_NOFUNC, 0)			/* User parameter is invalid */
#define OMCR_ERR_USER_NULLPOINTER				ERROR_CODE(MEAN_ERROR, TYPE_USERPARAM, FUNC_NOFUNC, 1)			/* Pointer of user parameter is NULL */

#define OMCR_ERR_DEV_NOCONNECTED				ERROR_CODE(MEAN_ERROR, TYPE_DEVICE, FUNC_NOFUNC, 0)				/* Communication is no connecting */
#define OMCR_ERR_DEV_NORESPONSE					ERROR_CODE(MEAN_ERROR, TYPE_DEVICE, FUNC_NOFUNC, 1)				/* Communication is no response */
#define OMCR_ERR_DEV_BUSY						ERROR_CODE(MEAN_ERROR, TYPE_DEVICE, FUNC_NOFUNC, 2)				/* Now on communicating by other process */
#define OMCR_ERR_DEV_RESTRICTED					ERROR_CODE(MEAN_ERROR, TYPE_DEVICE, FUNC_NOFUNC, 3)				/* Now on locking by other process */

#define OMCR_ERR_FUNC_DEV_WAITINITIAL			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 0)			/* Card Reader is waiting InitialReset */
#define OMCR_ERR_FUNC_DEV_MEDIAJAM				ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 1)			/* Card JAM */
#define OMCR_ERR_FUNC_DEV_SHUTTERFAIL			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 2)			/* Shutter fail */
#define OMCR_ERR_FUNC_DEV_LOCKFAIL				ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 2)			/* Lock fail */
#define OMCR_ERR_FUNC_DEV_ICCONTACTFAIL			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 3)			/* IC Contact fail */
#define OMCR_ERR_FUNC_DEV_WITHDRAWN				ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 4)			/* Withdrawn */
#define OMCR_ERR_FUNC_DEV_ICCARDMOVING			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 5)			/* IC card moved in activating */
#define OMCR_ERR_FUNC_DEV_CARDMOVING			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 5)			/* IC card moved in activating */
#define OMCR_ERR_FUNC_DEV_REINTAKEJAM			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 6)			/* Card Jammed in reintaking */
#define OMCR_ERR_FUNC_DEV_REARJAM				ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 7)			/* Card jammed in rear position */
#define OMCR_ERR_FUNC_DEV_REARDESTROYED			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 7)			/* Card jammed in rear position */
#define OMCR_ERR_FUNC_DEV_MAINTAINING			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 8)			/* Maintenance process is running */
#define OMCR_ERR_FUNC_DEV_MAINTAINED			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 9)			/* Maintenance process was finished */
#define OMCR_ERR_FUNC_DEV_HOSTWDTEJECT			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 10)			/* Host Card Ejection Occurred */
#define OMCR_ERR_FUNC_DEV_HOSTWDTRESET			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 11)			/* Host Card Reset Occurred */
#define OMCR_ERR_FUNC_DEV_TAMPERERROR			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DEVICE, 12)			/* Tamper switch was detected */

#define OMCR_ERR_FUNC_SOFT_FIRMWARE_BROKEN		ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_SOFTWARE, 0)		/* Firmware is broken */
#define OMCR_ERR_FUNC_SOFT_PARTIALFIRM_BROKEN	ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_SOFTWARE, 1)		/* Partial firmware is broken */

#define OMCR_ERR_FUNC_CMD_ENCRYPTNOTSTART		ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_COMMAND, 0)			/* Encrypted transmission is not started */
#define OMCR_ERR_FUNC_CMD_CANNOTDECRYPT			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_COMMAND, 1)			/* Cannot decrypt */

#define OMCR_ERR_FUNC_DL_CARDPRESENT			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DOWNLOAD, 0)		/* Card is in Card Reader */
#define OMCR_ERR_FUNC_DL_INVALID_DLFILE			ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DOWNLOAD, 1)		/* File is not download file */
#define OMCR_ERR_FUNC_DL_VERSION_NOTMATCH		ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DOWNLOAD, 2)		/* DL file does not match CPU version */
#define OMCR_ERR_FUNC_DL_DOWNLOAD_FAILURE		ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_DOWNLOAD, 3)		/* Download soft is broken */

#define OMCR_ERR_NOERRORCODE					ERROR_CODE(MEAN_ERROR, TYPE_IMCRWFUNC, FUNC_UNKNOWN, 0)			/* Unknown error */

/*------------------------------------------------------------------------------
 Warning statuses
-------------------------------------------------------------------------------*/
#define OMCR_STATUS_CANCELLED					ERROR_CODE(MEAN_WARNING, TYPE_NOTYPE, FUNC_NOFUNC, 0)

#define OMCR_WRN_DEV_ALREADYRESTRICTED			ERROR_CODE(MEAN_WARNING, TYPE_DEVICE, FUNC_NOFUNC, 0)			/* This process is already restricted */
#define OMCR_WRN_DEV_NOTRESTRICTED				ERROR_CODE(MEAN_WARNING, TYPE_DEVICE, FUNC_NOFUNC, 1)			/* This process is not restricted */

#define OMCR_WRN_FUNC_CMD_UNDEFINED				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_COMMAND, 0)		/* Undefined command */
#define OMCR_WRN_FUNC_CMD_SEQUENCE				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_COMMAND, 1)		/* Sequence error */
#define OMCR_WRN_FUNC_CMD_PARAMETER				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_COMMAND, 2)		/* Parameter error */
#define OMCR_WRN_FUNC_CMD_TRACKERROR			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_COMMAND, 3)		/* Designated write track error */

#define OMCR_WRN_FUNC_SOFT_DATAAREAERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SOFTWARE, 0)		/* Data error in FLASH area */

/* Mag. read/write error */
#define OMCR_WRN_FUNC_MAG_READERR_SS			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 0)		/* Mag. read error (SS cannot be detected) */
#define OMCR_WRN_FUNC_MAG_READERR_ES			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 1)		/* Mag. read error (ES cannot be detected) */
#define OMCR_WRN_FUNC_MAG_READERR_VRC			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 2)		/* Mag. read error (VRC is error) */
#define OMCR_WRN_FUNC_MAG_READERR_LRC			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 3)		/* Mag. read error (LRC is error) */
#define OMCR_WRN_FUNC_MAG_READERR_NOTENCODED	ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 4)		/* Mag. read error (The data is not encoded) */
#define OMCR_WRN_FUNC_MAG_READERR_NODATA		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 5)		/* Mag. read error (There is no data in Mag.) */
#define OMCR_WRN_FUNC_MAG_READERR_JITTER		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 6)		/* Mag. read error (Jitter over) */
#define OMCR_WRN_FUNC_MAG_READERR_LOWLEVEL		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 8)		/* Mag. read error (Low level) */
#define OMCR_WRN_FUNC_MAG_READERR_NOTRACK		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD, 9)		/* Mag. read error */
#define OMCR_WRN_FUNC_MAG_READERR_CARDHELD		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,10)		/* Mag. read error */

#define OMCR_WRN_FUNC_MAG_WRITEERR_SS			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,16)		/* Mag. write error (SS cannot be detected) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_ES			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,17)		/* Mag. write error (ES cannot be detected) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_VRC			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,18)		/* Mag. write error (VRC is error) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_LRC			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,19)		/* Mag. write error (LRC is error) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_NOTENCODED	ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,20)		/* Mag. write error (The data is not encoded) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_DISCODANCE	ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,21)		/* Mag. write error (The written data discode) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_JITTER		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,22)		/* Mag. write error (Jitter over) */
#define OMCR_WRN_FUNC_MAG_WRITEERR_LOWLEVEL		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MAGCARD,23)		/* Mag. write error (Low level) */

/* Security error */
#define OMCR_WRN_FUNC_SEC_NOTEQUIP				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 0)		/* CIM/MM is not equiped */
#define OMCR_WRN_FUNC_SEC_NORESPONSE			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 1)		/* Cannot receive from CIM/MM */
#define OMCR_WRN_FUNC_SEC_COMMERROR				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 2)		/* Communication error with CIM/MM */
#define OMCR_WRN_FUNC_SEC_DATAERROR				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 3)		/* Cannot read ISO3 data */
#define OMCR_WRN_FUNC_SEC_KEYNONE				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 4)		/* DES key is not set */
#define OMCR_WRN_FUNC_SEC_KEYINVALID			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 5)		/* DES key is invalid */
#define OMCR_WRN_FUNC_SEC_NOMMTRACK				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 6)		/* A card doesn't have CIM/MM track */
#define OMCR_WRN_FUNC_SEC_INVALIDDATA			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SECURITY, 7)		/* Validiation is invalid */

/* Media */
#define OMCR_WRN_FUNC_MED_NOSTRIPEMEDIA			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 0)			/* No stripe media inserted */
#define OMCR_WRN_FUNC_MED_NOCHIPMEDIA			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 1)			/* No chip media inserted */
#define OMCR_WRN_FUNC_MED_TOOLONG				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 2)			/* Card is too long */
#define OMCR_WRN_FUNC_MED_TOOSHORT				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 3)			/* Card is too short */
#define OMCR_WRN_FUNC_MED_CANNOTREINTAKE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 4)			/* Card cannot be re-intake */
#define OMCR_WRN_FUNC_MED_INTAKETIMEOUT			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 5)			/* Timeout in intaking */
#define OMCR_WRN_FUNC_MED_WITHDRAWTIMEOUT		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 6)			/* Timeout in withdrawing */
#define OMCR_WRN_FUNC_MED_REINTAKETIMEOUT		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 7)			/* Timeout in re-intaking */
#define OMCR_WRN_FUNC_MED_RETAINMEDIA			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 8)			/* Card is retained in initial reset */
#define OMCR_WRN_FUNC_MED_CANNOTLOCK			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_MEDIA, 9)			/* Cannot close the lock by card insertion*/

/* BIN */
#define OMCR_WRN_FUNC_BIN_FULL					ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_BIN, 0)			/* BIN is full */

/* Chip */
#define OMCR_WRN_FUNC_CHIP_CANNOTRECEIVE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 0)		/* IC receive over size data / PTS is not completed */
#define OMCR_WRN_FUNC_CHIP_ACTIVATEERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 1)		/* IC activation error */
#define OMCR_WRN_FUNC_CHIP_COMMUNICATEERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 2)		/* IC communication time out */
#define OMCR_WRN_FUNC_CHIP_FORCETERMINATE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 3)		/* Receive S(Abort,Seq) */
#define OMCR_WRN_FUNC_CHIP_RECEIVEDATAERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 4)		/* Receive invalid data or block */
#define OMCR_WRN_FUNC_CHIP_UNSUPPORTED			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 5)		/* ATR is unknown */
#define OMCR_WRN_FUNC_CHIP_VERIFYERROR			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 6)		/* Verification code is wrong */
#define OMCR_WRN_FUNC_CHIP_INAPPROVALVERIFY		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CHIPCARD, 7)		/* Rejection verification */

/* Contactless */
#define OMCR_WRN_FUNC_CLS_ACTIVATEERROR			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CONTACTLESS, 0)	/* Contactless IC activation error */
#define OMCR_WRN_FUNC_CLS_CANNOTRECEIVE			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CONTACTLESS, 1)	/* Contactless communication time out (withdraw) */
#define OMCR_WRN_FUNC_CLS_COMMUNICATEERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CONTACTLESS, 2)	/* Contactless communication failed (CRC error, etc) */
#define OMCR_WRN_FUNC_CLS_AUTHERROR				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CONTACTLESS, 3)	/* Authentication failed */
#define OMCR_WRN_FUNC_CLS_UNSUPPORTED			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_CONTACTLESS, 4)	/* This command is unsupported */

/* SAM */
#define OMCR_WRN_FUNC_SAM_CANNOTRECEIVE			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 0)			/* SAM receive over size data / PTS is not completed */
#define OMCR_WRN_FUNC_SAM_ACTIVATEERROR			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 1)			/* SAM activation error */
#define OMCR_WRN_FUNC_SAM_COMMUNICATEERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 2)			/* SAM communication error */
#define OMCR_WRN_FUNC_SAM_FORCETERMINATE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 3)			/* Receive S(Abort,Seq) */
#define OMCR_WRN_FUNC_SAM_RECEIVEDATAERROR		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 4)			/* Receive invalid data or block */
#define OMCR_WRN_FUNC_SAM_UNSUPPORTED			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 5)			/* ATR is unknown */
#define OMCR_WRN_FUNC_SAM_WITHDRAWAL			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_SAM, 6)			/* SAM is withdrawn */


#define OMCR_WRN_FUNC_BAT_ON_POWERFAILURE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_BATTERY, 0)		/* CROPF is activating (Power failure is detected) */
#define OMCR_WRN_FUNC_BAT_ON_HOSTDOWN			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_BATTERY, 1)		/* CROPF is activating (Host down) */
#define OMCR_WRN_FUNC_BAT_OFF_POWERFAILURE		ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_BATTERY, 3)		/* No action is activating (Power failure is detected) */
#define OMCR_WRN_FUNC_BAT_OFF_HOSTDOWN			ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_BATTERY, 4)		/* No action is activating (Host down) */

#define OMCR_WRN_FUNC_DIA_TOOFAST				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_DIAGNOSTIC, 0)	/* Card speed is too fast */
#define OMCR_WRN_FUNC_DIA_TOOSLOW				ERROR_CODE(MEAN_WARNING, TYPE_IMCRWFUNC, FUNC_DIAGNOSTIC, 1)	/* Card speed is too slow */

/*==============================================================================
 End of file
==============================================================================*/
#endif
