/**********************************************************************************************************
*
*	Copyright(C) 2002 - 2003 by OMRON Corporation
*		All Rights Reserved.
*
*	Copyright(C) 2004 - 2006 by Hitachi-Omron Terminal Solutions, Corp.
*		All Rights Reserved.
*
*	Name		: Hitachi-Omron Card Reader DLL Header File
*
*	Filename	: OMCR.H
*
*	Caption		: Standard/common definitions and declarations
*
*	Author		: Hitachi-Omron Terminal Solutions, Corp.
*
*	Revision	: 1.5.0.0
*
*	History		: 
*	-------------------------------------------------------------------------------------------------------
*	Revision	Date		Author			Description
*	-------------------------------------------------------------------------------------------------------
*	1.0.0.0		2003/10/28	OMRON			Create new
*	1.1.0.0		2003/11/20	OMRON			Added FindFirst, FindRec, FindClose
*											and RecoverFromRearDestroy APIs
*	1.2.0.0		2003/02/25	OMRON			Added 5 SAM Operations
*												(Added OMCR_GetSAMStatus
*												modified OMCR_GetStatus, OMCR_GetCapabilities)
*											Added OMCR_SendCommand
*											Added error informations of memory card to OMCR_ERRORCOUNT
*	1.3.0.0		2005/04/26	Hitachi-Omron	Changed the company name
*	1.4.0.0		2005/11/07	Hitachi-Omron	Modified Contactless option (OMCR_GetCapabilities)
*											Added OMCR_SetHostWDTReset
* 											Added OMCR_VER_SAMFIRM for OMCR_GetVersion
*	1.5.0.0		2006/04/03	Hitachi-Omron	Added Contactless Functions
*											<API>
*												OMCR_ActivateContactless, OMCR_DeactivateContactless
*												OMCR_MifareAuthenticate, OMCR_MifareRead, OMCR_MifareWrite
*												OMCR_TypeBAttribute, OMCR_TypeBCommunication are added
*												OMCR_RecoverFromRearDestroy is deleted
*											<Structure>
*												OMCR_CLESSINFO, OMCR_TYPEB_ATTRIB
*											<Define>
*												OMCR_CLESS_MIFARE, OMCR_CLESS_TYPEB
*												Attribute structure OMCR_TYPEB_*
*											Added AT24C* memory cards define (OMCR_MCARD_AT24C*)
*											OMCR_SET_ICSTD_MONEO was added
*
*************************************************************************************************************/

#ifndef __OMRON_OMCR_API_DLL_HEADER__
#define __OMRON_OMCR_API_DLL_HEADER__

#ifdef OMCRAPI_EXPORTS
#define OMCR_API __declspec(dllexport)
#else
#define OMCR_API __declspec(dllimport)
#endif

#include "stdafx.h"


// Error Code Definitions
#define OMCR_ERROR_CODE_DEFINE
#if defined(OMCR_ERROR_CODE_DEFINE)
	#include "ErrorCode.h"
#endif


/*******************************************************************************
	Define Section
*******************************************************************************/

#ifndef IN
	#define IN
#endif
#ifndef OUT
	#define OUT
#endif


/*******************************************************************************
	Structure Section
*******************************************************************************/

/****** Pointer to OMCR ******/
typedef struct {
	LPCSTR	lpcszDevice;					/* Type of device ("USB", or "COM") */
	HANDLE	hDevice;						/* Handle of device */
	LPCVOID	lpcDevice;						/* Pointer */
} OMCR, *LPOMCR;
typedef const OMCR				*LPCOMCR;


/****** Option for OMCR and DLL ******/
typedef struct {
	union {
		struct {
			LPVOID		lpvReserved0;		/* reservation 0 */
			DWORD		dwBaudRate;			/* Transmission speed */
			DWORD		dwReserved1;		/* reserved */
			DWORD		dwReserved2;		/* reserved */
			DWORD		dwReserved3;		/* reserved */
			LPVOID		lpvReserved1;		/* reservation 1(set NULL) */
			LPVOID		lpvReserved2;		/* reservation 2(set NULL) */
		} COM;
		struct {
			DWORD	dwReserved0;			/* reserved */
			DWORD	dwReserved1;			/* reserved */
			DWORD	dwReserved2;			/* reserved */
			DWORD	dwReserved3;			/* reserved */
		} USB;
	} Device;
} OMCR_OPTION, LPOMCR_OPTION;
typedef const OMCR_OPTION		*LPCOMCR_OPTION;

/****** Find Record ******/
typedef struct{
	DWORD	cbSize;							/* Size of the variable */
	LPVOID	lpCtrlInfo;						/* Pointer of the control information */
	LPSTR	lpszManufacturer;				/* String from iManufacturer StringDescriptor */
	LPSTR	lpszProduct;					/* String from iProduct StringDescriptor */
	LPSTR	lpszSerialNumber;				/* String from iSerialNumber StringDescriptor */
	USHORT	VendorID;						/* Vendor ID from DviceDescriptor */
	USHORT	ProductID;						/* Product ID from DviceDescriptor */
	USHORT	VersionNumber;					/* Version from DviceDescriptor */
	USHORT	uReserved;						/* reserved */
	DWORD	dwMaxSendBufferSize;			/* Maximum buffer size of sending */
	DWORD	dwMaxReceiveBufferSize;			/* Maximum buffer size of receiving */
} OMCR_FINDREC, *LPOMCR_FINDREC;

/****** Voltage of sensors ******/
typedef struct {
	DWORD	dwS1;							/* Sensor 1 voltage */
	DWORD	dwS2;							/* Sensor 2 voltage */
	DWORD	dwLock;							/* Echo sensor of shutter */
	DWORD	dwSpare;						/* Extra */
} OMCR_SENSOR, *LPOMCR_SENSOR;
typedef const OMCR_SENSOR		*LPCOMCR_SENSOR;


/****** Firmware version information ******/
typedef struct{
	char	strType[13];					/* Type "HBU-NAxxx  " */
	char	strRevision[3];					/* Revision */
	DWORD	dwSum;							/* Sum value */
} OMCR_VERSION, *LPOMCR_VERSION;
typedef const OMCR_VERSION		*LPCOMCR_VERSION;


/****** Options for transaction settings ******/
typedef struct{
	DWORD	dwReadDirection;				/* Magnetic read direction */
	DWORD	dwReadTracks;					/* Magnetic read tracks */
	DWORD	bInsert;						/* Shutter-locking when card is inserted */
	DWORD	bPullout;						/* Shutter-locking when card is pulled-out */
} OMCR_SETTINGS, *LPOMCR_SETTINGS;
typedef const OMCR_SETTINGS		*LPCOMCR_SETTINGS;


/****** Card status monitoring information ******/
typedef struct{
	DWORD	dwTrack1;						/* ISO #1 read result */
	DWORD	dwTrack2;						/* ISO #2 read result */
	DWORD	dwTrack3;						/* ISO #3 read result */
	DWORD	dwSpare1;						/* Spare 1 */
	DWORD	dwSpare2;						/* Spare 2 */
} OMCR_CARDSTATUS, *LPOMCR_CARDSTATUS;
typedef const OMCR_CARDSTATUS	*LPCOMCR_CARDSTATUS;


/****** Error count information ******/
typedef struct{
	ULONG	uIso1InsertionReadErrCnt;		/* Number of ISO #1 insertion read error occurrences */
	ULONG	uIso2InsertionReadErrCnt;		/* Number of ISO #2 insertion read error occurrences */
	ULONG	uIso3InsertionReadErrCnt;		/* Number of ISO #3 insertion read error occurrences */
	ULONG	uSpare1;						/* Spare */
	ULONG	uIso1BackwardReadErrCnt;		/* Number of ISO #1 back read error occurrences */
	ULONG	uIso2BackwardReadErrCnt;		/* Number of ISO #2 back read error occurrences */
	ULONG	uIso3BackwardReadErrCnt;		/* Number of ISO #3 back read error occurrences */
	ULONG	uSpare2;						/* Spare */
	ULONG	uICActivation;					/* Number of IC activation error occurrences */
	ULONG	uICCommunication;				/* Number of IC communication error occurrences */
	ULONG	uSAMActivation;					/* Number of SAM activation error occurrences */
	ULONG	uSAMCommunication;				/* Number of SAM communication error occurrences */
	ULONG	uMemCardActivation;				/* Number of memory card activation error occurrences */
	ULONG	uMemCardCommunication;			/* Number of memory card communication error occurrences */
	ULONG	uSpare5;						/* Spare */
	ULONG	uSpare6;						/* Spare */
} OMCR_ERRORCOUNT, *LPOMCR_ERRORCOUNT;
typedef const OMCR_ERRORCOUNT	*LPCOMCR_ERRORCOUNT;


/****** Action count information ******/
typedef struct{
	ULONG	uCardInsertionCount;			/* Number of insertion of a card */
	ULONG	uLockCount;						/* Number of times the device is locked */
	ULONG	uInsertionReadCount;			/* Number of insertion-reading occurrences */
	ULONG	uBackReadCount;					/* Number of pullout-reading occurrences */
} OMCR_ACTIONCOUNT, *LPOMCR_ACTIONCOUNT;
typedef const OMCR_ACTIONCOUNT	*LPCOMCR_ACTIONCOUNT;


/****** Magnetic track data ******/
typedef struct {
	DWORD	dwTrackStatus[3];				/* The status of operation */
	BYTE	bTrackLen[3];					/* The length of each track */
	BYTE	bTrack1[77];					/* The data of track 1 */
	BYTE	bTrack2[38];					/* The data of Track 2 */
	BYTE	bTrack3[105];					/* The data of track 3 */
} OMCR_MAGTRACK, *LPOMCR_MAGTRACK;
typedef const OMCR_MAGTRACK		*LPCOMCR_MAGTRACK;


/****** Chip IO Data ******/
typedef struct{
	DWORD	dwProtocol;						/* Protocol */
	ULONG	uLength;						/* Data length */
	BYTE	bData[2048];					/* Data */
} OMCR_ICCIO, *LPOMCR_ICCIO;
typedef const OMCR_ICCIO		*LPCOMCR_ICCIO;

/****** Contactless ******/
typedef struct {
	ULONG	cbSize;							/* = sizeof(OMCR_CLESSINFO) */
	BYTE	nMifareNumber;					/* The number of detected Mifare */
	BYTE	nTypeBNumber;					/* The number of detected TypeB */
	BYTE	bReserved1;						/* Reserved */
	BYTE	bReserved2;						/* Reserved */
	struct {
		DWORD dwFlag;						/* The identifier of next 16 bytes */
											/*   (OMCR_CLESS_MIFARE or OMCR_CLESS_TYPEB) */
		union {
			struct {
				BYTE	SNR[4];				/* Serial Number of Mifare card */
				BYTE	RFU[12];			/* RFU */
			} Mifare;
			struct {
				BYTE	ID[4];				/* ID of TypeB card */
				BYTE	ApInfo[4];			/* Application Infomation */
				BYTE	Protocol[3];		/* Protocol Information */
				BYTE	RFU[5];				/* RFU */
			} TypeB;
		} ClessInfo;
	} ATR[99];
} OMCR_CLESSINFO, *LPOMCR_CLESSINFO;
typedef const OMCR_CLESSINFO	*LPCOMCR_CLESSINFO;

/* Please refer ISO/IEC 14443-3 for detail */
typedef struct {
	DWORD	cbSize;							/* = sizeof(OMCR_TYPEB_ATTRIB) */
	/* Param1 */
	BOOL	bSOF;							/* SOF break required */
	BOOL	bEOF;							/* EOF break required */
	BYTE	bTR0;							/* The PICCs the minimum delay before responding after the end of a command sent by OMCR */
	BYTE	bTR1;							/* The PICCs the minimum delay between subcarrier modulation start and beginning of data transmission */
	BYTE	bRFUParam1;						/* Upper 2 bits of Param1 */
	/* Param2 */
	BYTE	bFrameSize;						/* The maximum frame size that can be received by OMCR */
	BYTE	bSpeedToCard;					/* Transmission speed from OMCR to the PICC */
	BYTE	bSpeedToCR;						/* Transmission speed from the PICC to OMCR */
	/* Param3 */
	BYTE	bProtocolType;					/* Protocol Type */
	BYTE	bRFUParam3;						/* Upper 4 bits of Param3 */
	/* Param4 */
	BYTE	bCID;							/* Card IDentifier (0-14, 15 is RFU) */
	BYTE	bRFUParam4;						/* Upper 4 bits of Param4 */
} OMCR_TYPEB_ATTRIB, *LPOMCR_TYPEB_ATTRIB;
typedef const OMCR_TYPEB_ATTRIB	*LPCOMCR_TYPEB_ATTRIB;

/****** Capability information ******/
typedef struct{
	BOOL	bBatteryPresence;				/* UPS Setting */
	DWORD	dwSamSupport;					/* SAM supporting */
	WORD	fwContactless;					/* Contactless supporting */
} OMCR_CAPABILITY_EX, *LPOMCR_CAPABILITY_EX;

typedef struct{
	WORD	fwType;							/* CR Model (Motor/DIP/Swipe/Contactless) */
	BOOL	bCompound;						/* Logical device */
	WORD	fwReadTracks;					/* Readable tracks */
	WORD	fwWriteTracks;					/* Writable tracks */
	WORD	fwChipProtocols;				/* Chip protocol supporting */
	USHORT	usCards;						/* Number of cards retain bin can hold */ /* not included in V2XU-DLL */
	WORD	fwSecType;						/* Security type */
	WORD	fwPowerOnOption;				/* Motion in Power on */
	WORD	fwPowerOffOption;				/* Motion in Power off */
	BOOL	bFluxSensorProgrammable;		/* Flux sensor programmable */
	BOOL	bReadWriteAccessFollowingEject;	/* Read write access following eject */
	WORD	fwWriteMode;					/* Writting mode */
	WORD	fwChipPower;					/* Chip power management */
	OMCR_CAPABILITY_EX	ExCapability;		/* Extra capability information */
} OMCR_CAPABILITY, *LPOMCR_CAPABILITY;
typedef const OMCR_CAPABILITY	*LPCOMCR_CAPABILITY;


/****** Status information ******/
typedef struct{
	WORD	fwBatteryStatus;				/* Battery Status */
	WORD	fwSamChip;						/* Presense SAM chips */
} OMCR_STATUS_EX, *LPOMCR_STATUS_EX;

typedef struct{
	WORD	fwDevice;						/* Device status */
	WORD	fwMedia;						/* Card Status */
	WORD	fwRetainBin;					/* BIN Status */
	WORD	fwSecurity;						/* CIM86/MM Status */
	USHORT	usCards;						/* Captured cards */
	WORD	fwChipPower;					/* Chip Status */
	OMCR_STATUS_EX	ExStatus;				/* Extra status information */
} OMCR_STATUS, *LPOMCR_STATUS;
typedef const OMCR_STATUS		*LPCOMCR_STATUS;



/*******************************************************************************
	Definitions and Macros Section
*******************************************************************************/

/* Undefined value */
#define OMCR_VALUE_UNDEFINED					0xFFFFFFFF

/************************************************
*				C/R Open Options				*
*************************************************/
/* Baud Rates */
#define OMCR_BAUDRATE_1200						1200
#define OMCR_BAUDRATE_2400						2400
#define OMCR_BAUDRATE_4800						4800
#define OMCR_BAUDRATE_9600						9600
#define OMCR_BAUDRATE_19200						19200
#define OMCR_BAUDRATE_38400						38400


/************************************************
*				C/R Capability					*
*************************************************/
/* capability class */
#define OMCR_CAPABILITY_EX_CLASS_UNKNOWN		0x00000000
#define OMCR_CAPABILITY_EX_CLASS_NONE			0x00000001
#define OMCR_CAPABILITY_EX_CLASS_TYPEA			0x00000002
#define OMCR_CAPABILITY_EX_CLASS_MIFARE			0x00000002
#define OMCR_CAPABILITY_EX_CLASS_TYPEB			0x00000004
#define OMCR_CAPABILITY_EX_CLASS_FELICA			0x00000008

/* dwSamSupport: Number Sam Supporting */
#define OMCR_CAPABILITY_EX_SAMNOTSUPP			0x00000000
#define OMCR_CAPABILITY_EX_1SAMSUPP				0x00000001
#define OMCR_CAPABILITY_EX_4SAMSUPP				0x00000002
#define OMCR_CAPABILITY_EX_5SAMSUPP				0x00000002

/* fwType */
#define OMCR_CAPABILITY_TYPEMOTOR				(1)
#define OMCR_CAPABILITY_TYPESWIPE				(2)
#define OMCR_CAPABILITY_TYPEDIP					(3)
#define OMCR_CAPABILITY_TYPECONTACTLESS			(4)

/* fwReadTracks / fwWriteTracks */
#define OMCR_CAPABILITY_NOTSUPP					0x0000
#define OMCR_CAPABILITY_TRACK1					0x0001
#define OMCR_CAPABILITY_TRACK2					0x0002
#define OMCR_CAPABILITY_TRACK3					0x0004

/* fwChipProtocols */
#define OMCR_CAPABILITY_T0						0x0001
#define OMCR_CAPABILITY_T1						0x0002

/* fwSecType */
#define OMCR_CAPABILITY_SECNOTSUPP				(1)
#define OMCR_CAPABILITY_SECMMBOX				(2)
#define OMCR_CAPABILITY_SECCIM86				(3)

/* fwPowerOnOption / fwPowerOffOption */
#define OMCR_CAPABILITY_NOACTION				(1)
#define OMCR_CAPABILITY_EJECT					(2)
#define OMCR_CAPABILITY_RETAIN					(3)
#define OMCR_CAPABILITY_EJECTTHENRETAIN			(4)
#define OMCR_CAPABILITY_READPOSITION			(5)

/* fwWriteMode */
#define OMCR_CAPABILITY_UNKNOWN					0x0001
#define OMCR_CAPABILITY_LOCO					0x0002
#define OMCR_CAPABILITY_HICO					0x0004
#define OMCR_CAPABILITY_AUTO					0x0008

/* fwChipPower */
#define OMCR_CAPABILITY_CHIPPOWERCOLD			0x0002
#define OMCR_CAPABILITY_CHIPPOWERWARM			0x0004
#define OMCR_CAPABILITY_CHIPPOWEROFF			0x0008


/************************************************
*				C/R Status						*
*************************************************/
/* fwBatteryStatus */
#define OMCR_STATUS_EX_BATTERY_NOTFULLCHARGED	0x00000001
#define OMCR_STATUS_EX_BATTERY_FULLCHARGED		0x00000002
#define OMCR_STATUS_EX_BATTERY_WARNING			0x00000003

/* fwSamChip */
#define OMCR_STATUS_EX_SAMPRESENCE_1			0x0001
#define OMCR_STATUS_EX_SAMPRESENCE_2			0x0002
#define OMCR_STATUS_EX_SAMPRESENCE_3			0x0004
#define OMCR_STATUS_EX_SAMPRESENCE_4			0x0008
#define OMCR_STATUS_EX_SAMPRESENCE_5			0x0010

/* fwSamStatus */

/* All statuses are set UNKNOWN when an error occurs */
#define OMCR_STATUS_UNKNOWN						(0)				/* not defined in XFS */

/* fwDevice */
#define OMCR_STATUS_DEVONLINE					(0)
#define OMCR_STATUS_DEVOFFLINE					(1)
#define OMCR_STATUS_DEVPOWEROFF					(2)
#define OMCR_STATUS_DEVNODEVICE					(3)
#define OMCR_STATUS_DEVHWERROR					(4)
#define OMCR_STATUS_DEVUSERERROR				(5)
#define OMCR_STATUS_DEVBUSY						(6)

/* fwMedia */
#define OMCR_STATUS_MEDIAPRESENT				(1)
#define OMCR_STATUS_MEDIANOTPRESENT				(2)
#define OMCR_STATUS_MEDIAJAMMED					(3)
#define OMCR_STATUS_MEDIANOTSUPP				(4)
#define OMCR_STATUS_MEDIAUNKNOWN				(5)
#define OMCR_STATUS_MEDIAENTERING				(6)

/* fwRetainBin */
#define OMCR_STATUS_RETAINBINOK					(1)
#define OMCR_STATUS_RETAINNOTSUPP				(2)
#define OMCR_STATUS_RETAINBINFULL				(3)

/* fwSecurity */
#define OMCR_STATUS_SECNOTSUPP					(1)
#define OMCR_STATUS_SECNOTREADY					(2)
#define OMCR_STATUS_SECOPEN						(3)

/* fwChipPower */
#define OMCR_STATUS_CHIPONLINE					(0)
#define OMCR_STATUS_CHIPPOWEREDOFF				(1)
#define OMCR_STATUS_CHIPBUSY					(2)
#define OMCR_STATUS_CHIPNODEVICE				(3)
#define OMCR_STATUS_CHIPHWERROR					(4)
#define OMCR_STATUS_CHIPNOCARD					(5)
#define OMCR_STATUS_CHIPNOTSUPP					(6)
#define OMCR_STATUS_CHIPUNKNOWN					(7)


/************************************************
*				C/R LED Control					*
*************************************************/
/* LED Automatic Control Mode */
#define OMCR_LEDCTRLMODE_MANUAL					0x00000000
#define OMCR_LEDCTRLMODE_AUTOMATIC				0x00000001

/* LED Color */
#define OMCR_SET_LED_COLOR_GREEN				0x00000001
#define OMCR_SET_LED_COLOR_RED					0x00000002
#define OMCR_SET_LED_COLOR_ORANGE				0x00000003

/* LED Blinking Cycle */
#define OMCR_SET_LED_BLINK4HZ					0x00000000
#define OMCR_SET_LED_BLINK2HZ					0x00000001
#define OMCR_SET_LED_BLINK1HZ					0x00000002
#define OMCR_SET_LED_BLINK1_2HZ					0x00000003
#define OMCR_SET_LED_BLINK1_4HZ					0x00000004


/************************************************
*				C/R ICC and SAM					*
*************************************************/
/* ICC/SAM Standard Type */
#define OMCR_SET_ICSTD_ISO						0x00000000
#define OMCR_SET_ICSTD_SPECIAL01				0x00000004
#define OMCR_SET_ICSTD_EMV						0x00000005
#define OMCR_SET_ICSTD_ZKA						0x00000006
#define OMCR_SET_ICSTD_MONEO					0x00000008
#define OMCR_SET_ICSTD_UNKNOWN					0xFFFFFFFF

/* Communication protocol */
#define OMCR_CHIPIO_PROTOCOL_T0					0x00000001
#define OMCR_CHIPIO_PROTOCOL_T1					0x00000002

/* ICC/SAM activation */
#define OMCR_IC_COLDRESET						0x00000001		/* Cold reset */
#define OMCR_IC_WARMRESET						0x00000002		/* Warm reset */

/* Memory card activation */
#define OMCR_MCARD_SLE4442						0x00000000
#define OMCR_MCARD_SLE4432						0x00000001
#define OMCR_MCARD_SLE4428						0x00000002
#define OMCR_MCARD_SLE4418						0x00000003
#define OMCR_MCARD_AT24C01						0x00000004
#define OMCR_MCARD_AT24C02						0x00000004
#define OMCR_MCARD_AT24C016						0x00000004
#define OMCR_MCARD_AT24C064						0x00000005

/********************************************
*				Contactless					*
*********************************************/
/* dwFlag of OMCR_ActivateContactless and OMCR_CLESSINFO */
#define OMCR_CLESS_MIFARE			0x00000002
#define OMCR_CLESS_TYPEB			0x00000004

/* OMCR_TYPEB_ATTRIB */
/* bTR0 - Param1 */
#define OMCR_TYPEB_TR0_DEFAULT		0x00	/* Default */
#define OMCR_TYPEB_TR0_48F			0x01	/* 48/fs */
#define OMCR_TYPEB_TR0_16F			0x02	/* 16/fs */
/* bTR1 - Param1 */
#define OMCR_TYPEB_TR1_DEFAULT		0x00	/* Default */
#define OMCR_TYPEB_TR1_64F			0x01	/* 64/fs */
#define OMCR_TYPEB_TR1_16F			0x02	/* 16/fs */
/* bFrameSize - Param2 */
#define OMCR_TYPEB_FRAMESIZE_16		0x00	/* 16 bytes */
#define OMCR_TYPEB_FRAMESIZE_24		0x01	/* 24 bytes */
#define OMCR_TYPEB_FRAMESIZE_32		0x02	/* 32 bytes */
#define OMCR_TYPEB_FRAMESIZE_40		0x03	/* 40 bytes */
#define OMCR_TYPEB_FRAMESIZE_48		0x04	/* 48 bytes */
#define OMCR_TYPEB_FRAMESIZE_64		0x05	/* 64 bytes */
#define OMCR_TYPEB_FRAMESIZE_96		0x06	/* 96 bytes */
#define OMCR_TYPEB_FRAMESIZE_128	0x07	/* 128 bytes */
#define OMCR_TYPEB_FRAMESIZE_256	0x08	/* 256 bytes */
/* bSpeedToCR - Param2 */
#define OMCR_TYPEB_SPEED_106K		0x00	/* 106 bytes */
#define OMCR_TYPEB_SPEED_212K		0x01	/* 212 bytes */
#define OMCR_TYPEB_SPEED_424K		0x02	/* 424 bytes */
#define OMCR_TYPEB_SPEED_847K		0x03	/* 847 bytes */

/************************************************
*				Counters						*
*************************************************/
/* Clear ErrorCount counters */
#define OMCR_CLR_ERRCNT_ISO1_INSERTIONREAD		0x00000001
#define OMCR_CLR_ERRCNT_ISO2_INSERTIONREAD		0x00000002
#define OMCR_CLR_ERRCNT_ISO3_INSERTIONREAD 		0x00000004
#define OMCR_CLR_ERRCNT_SPARE1					0x00000008
#define OMCR_CLR_ERRCNT_ISO1_BACKWARDREAD		0x00000010
#define OMCR_CLR_ERRCNT_ISO2_BACKWARDREAD		0x00000020
#define OMCR_CLR_ERRCNT_ISO3_BACKWARDREAD		0x00000040
#define OMCR_CLR_ERRCNT_SPARE2					0x00000080
#define OMCR_CLR_ERRCNT_IC_ACTIVATE				0x00000100
#define OMCR_CLR_ERRCNT_IC_COMMUNICATE			0x00000200
#define OMCR_CLR_ERRCNT_SAM_ACTIVATE			0x00000400
#define OMCR_CLR_ERRCNT_SAM_COMMUNICATE			0x00000800
#define OMCR_CLR_ERRCNT_MEM_ACTIVATE			0x00001000
#define OMCR_CLR_ERRCNT_MEM_COMMUNICATE			0x00002000
#define OMCR_CLR_ERRCNT_SPARE5					0x00004000
#define OMCR_CLR_ERRCNT_SPARE6					0x00008000
#define OMCR_CLR_ERRCNT_ALL						OMCR_CLR_ERRCNT_ISO1_INSERTIONREAD	| \
												OMCR_CLR_ERRCNT_ISO2_INSERTIONREAD	| \
												OMCR_CLR_ERRCNT_ISO3_INSERTIONREAD	| \
												OMCR_CLR_ERRCNT_SPARE1				| \
												OMCR_CLR_ERRCNT_ISO1_BACKWARDREAD	| \
												OMCR_CLR_ERRCNT_ISO2_BACKWARDREAD	| \
												OMCR_CLR_ERRCNT_ISO3_BACKWARDREAD	| \
												OMCR_CLR_ERRCNT_SPARE2				| \
												OMCR_CLR_ERRCNT_IC_ACTIVATE			| \
												OMCR_CLR_ERRCNT_IC_COMMUNICATE		| \
												OMCR_CLR_ERRCNT_SAM_ACTIVATE		| \
												OMCR_CLR_ERRCNT_SAM_COMMUNICATE		| \
												OMCR_CLR_ERRCNT_MEM_ACTIVATE		| \
												OMCR_CLR_ERRCNT_MEM_COMMUNICATE		| \
												OMCR_CLR_ERRCNT_SPARE5				| \
												OMCR_CLR_ERRCNT_SPARE6

/* Clear ActionCount counters */
#define OMCR_CLR_ACTCNT_CARDINSERTIONCOUNT		0x00000001
#define OMCR_CLR_ACTCNT_LOCKCOUNT				0x00000002
#define OMCR_CLR_ACTCNT_INSERTIONREADCOUNT		0x00000004
#define OMCR_CLR_ERRCNT_BACKREADCOUNT			0x00000008
#define OMCR_CLR_ACTCNT_ALL						OMCR_CLR_ACTCNT_CARDINSERTIONCOUNT	| \
												OMCR_CLR_ACTCNT_LOCKCOUNT			| \
												OMCR_CLR_ACTCNT_INSERTIONREADCOUNT	| \
												OMCR_CLR_ERRCNT_BACKREADCOUNT


/************************************************
*				FW version						*
*************************************************/
/* FW Version Type */
#define OMCR_VER_MASK							0x00000001		/* Mask version */
#define OMCR_VER_FIRM							0x00000002		/* Main firm ware */
#define OMCR_VER_ICFIRM		 					0x00000003		/* Chip partial firmware */
#define OMCR_VER_SAMFIRM						0x00000004		/* SAM partial firmware */

/************************************************
*				Magnetic Tracks					*
*************************************************/
/* Transaction settings */
#define OMCR_SET_TRANS_NOREADING				0x00000000
#define OMCR_SET_TRANS_INSERTIONREADING			0x00000001
#define OMCR_SET_TRANS_BACKREADING				0x00000002

/* Magnetic tracks */
#define OMCR_READ_TRACK_ISO1					0x00000001
#define OMCR_READ_TRACK_ISO2					0x00000002
#define OMCR_READ_TRACK_ISO3					0x00000004

/* Card status properties */
#define OMCR_CARD_STATUS_NOREADING				0x00000000
#define OMCR_CARD_STATUS_READSUCCESS			0x00000001
#define OMCR_CARD_STATUS_READERROR				0x00000002
#define OMCR_CARD_STATUS_NOREADDATA				0x00000003



/*******************************************************************************
	Interface Section
*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif


OMCR_API LPCOMCR WINAPI		OMCR_OpenDevice
(
	IN	LPCSTR				lpcszDevice,
	IN	LPCOMCR_OPTION		lpcOption
);

OMCR_API DWORD	WINAPI		OMCR_CloseDevice
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_EnumerateDevices
(
	OUT	PULONG				puNumber
);

OMCR_API DWORD	WINAPI		OMCR_FindFirst
(
	OUT	LPOMCR_FINDREC		lpFindRec
);

OMCR_API DWORD	WINAPI		OMCR_FindNext
(
	IN OUT	LPOMCR_FINDREC	lpFindRec
);

OMCR_API void	WINAPI		OMCR_FindClose
(
	IN	LPOMCR_FINDREC		lpFindRec
);

OMCR_API DWORD	WINAPI		OMCR_GetResult
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_Cancel
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_StartRestriction
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_EndRestriction
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_GetCapabilities
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPOMCR_CAPABILITY	lpCapability,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetStatus
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPOMCR_STATUS		lpStatus,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_InitialReset
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_PrepareTransactionSetting
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_SETTINGS	lpcSettings,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_MonitorCardStatus
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwMonitor,
	OUT LPOMCR_CARDSTATUS	lpCardStatus,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_ReadMagTrack
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwTrackFlag,
	OUT LPOMCR_MAGTRACK		lpMagTrack,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_ClearReadData
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_Lock
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_Unlock
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_ActivateICC
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwFlag,
	OUT LPOMCR_ICCIO		lpAtr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_DeactivateICC
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_CommunicateICC
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_ICCIO		lpcIn,
	OUT LPOMCR_ICCIO		lpOut,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_ActivateSAM
(
	IN	LPCOMCR				lpcOmcr,
	IN	ULONG				uSam,
	IN	DWORD				dwFlag,
	OUT LPOMCR_ICCIO		lpAtr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_DeactivateSAM
(
	IN	LPCOMCR				lpcOmcr,
	IN	ULONG				uSam,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_CommunicateSAM
(
	IN	LPCOMCR				lpcOmcr,
	IN	ULONG				uSam,
	IN	LPCOMCR_ICCIO		lpcIn,
	OUT LPOMCR_ICCIO		lpOut,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetSAMStatus
(
	IN	LPCOMCR				lpcOmcr,
	IN	ULONG				uSam,
	OUT LPWORD				lpfwSamPower,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_ActivateMemoryCard
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwFlag,
	OUT	LPOMCR_ICCIO		lpAtr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_DeactivateMemoryCard
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_CommunicateMemoryCard
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_ICCIO		lpcIn,
	OUT	LPOMCR_ICCIO		lpOut,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_VerifyMemoryCard
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_ICCIO		lpcIn,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_ActivateContactless
(
	IN		LPCOMCR				lpcOmcr,
	IN		DWORD				dwFlag,
	IN		DWORD				dwWaitTime,
	IN OUT	LPOMCR_CLESSINFO	lpClessInfo, 
	IN		HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_DeactivateContactless
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_MifareAuthenticate
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_CLESSINFO	lpcClessInfo,
	IN	BYTE				nCard,
	IN	BYTE				bKeyType,
	IN	BYTE				bSector,
	IN	const BYTE*			lpcAuthenticationKey,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_MifareRead
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_CLESSINFO	lpcClessInfo,
	IN	BYTE				nCard,
	IN	BYTE				bAddress,
	OUT	BYTE*				lpData,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_MifareWrite
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_CLESSINFO	lpcClessInfo,
	IN	BYTE				nCard,
	IN	BYTE				bAddress,
	IN	const BYTE*			lpcData,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI		OMCR_TypeBAttribute
(
	IN	LPCOMCR					lpcOmcr,
	IN	LPCOMCR_CLESSINFO		lpcClessInfo,
	IN	BYTE					nCard,
	IN	LPCOMCR_TYPEB_ATTRIB	lpcAttrib,
	IN	LPCOMCR_ICCIO			lpcIn,
	OUT	LPOMCR_ICCIO			lpOut,
	IN	HANDLE					hEvent
);

OMCR_API DWORD WINAPI		OMCR_TypeBCommunication
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCOMCR_CLESSINFO	lpcClessInfo,
	IN	BYTE				nCard,
	IN	LPCOMCR_ICCIO		lpcIn,
	OUT	LPOMCR_ICCIO		lpOut,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_TurnonLED
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwColor,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_TurnoffLED
(
	IN	LPCOMCR				lpcOmcr,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_BlinkLED
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwColor,
	IN	DWORD				dwCycle,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_CreateNewSessionKey
(
	IN	LPCOMCR				lpcOmcr
);

OMCR_API DWORD	WINAPI		OMCR_GetSensorLevel
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPOMCR_SENSOR		lpSensor,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetVersion
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwType,
	OUT LPOMCR_VERSION		lpVersion,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetSerialNumber
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPSTR				lpszSerial,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetModelNumber
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPSTR				lpszModel,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetErrorCount
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPOMCR_ERRORCOUNT	lpErrorCount,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetActionCount
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPOMCR_ACTIONCOUNT	lpActionCount,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetICCStandardType
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPDWORD				lpdwType,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_GetSAMStandardType
(
	IN	LPCOMCR				lpcOmcr,
	OUT LPDWORD				lpdwType,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_SetICCStandardType
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwType,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_SetSAMStandardType
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwType,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_SetLEDControlMode
(
	IN	LPCOMCR				lpcOmcr,
	IN	DWORD				dwMode,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_ExecuteDownload
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCSTR				lpcszFileName,
	IN	HANDLE				hEvent
);

OMCR_API DWORD	WINAPI		OMCR_LogErrorData
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPCSTR				lpcszLogData
);

OMCR_API DWORD WINAPI		OMCR_SendCommand
(
	IN	LPCOMCR				lpcOmcr,
	IN	LPBYTE				lpSend,
	IN	ULONG				uSend,
	IN	ULONG				uSendTimeOut,
	OUT	LPBYTE				lpRes,
	IN	ULONG				uRes,
	OUT	PULONG				puRes,
	IN	ULONG				uResTimeOut,
	IN	HANDLE				hEvent
);

OMCR_API DWORD WINAPI OMCR_SetHostWDTReset
(
	IN	LPCOMCR				lpcOmcr,
	IN	ULONG				uMonitoringTime,
	IN	ULONG				uResetNumber,
	IN	ULONG				uResetTime,
	IN	HANDLE				hEvent
);

#ifdef __cplusplus
}
#endif

#endif
